/*
Plugin: jQuery Parallax
Version 1.1.3
Author: Ian Lunn
Twitter: @IanLunn
Author URL: http://www.ianlunn.co.uk/
Plugin URL: http://www.ianlunn.co.uk/plugins/jquery-parallax/

Dual licensed under the MIT and GPL licenses:
http://www.opensource.org/licenses/mit-license.php
http://www.gnu.org/licenses/gpl.html
*/

(function( $ ){
	var $window = $(window);
	var windowHeight = $window.height();

	$window.resize(function () {
		windowHeight = $window.height();
	});

	$.fn.parallax = function(xpos, speedFactor, outerHeight) {
		var $this = $(this);
		var getHeight;
		var firstTop;
		var paddingTop = 0;
		
		//get the starting position of each element to have parallax applied to it		
		$this.each(function(){
		    firstTop = $this.offset().top;
		});

		if (outerHeight) {
			getHeight = function(jqo) {
				return jqo.outerHeight(true);
			};
		} else {
			getHeight = function(jqo) {
				return jqo.height();
			};
		}
			
		// setup defaults if arguments aren't specified
		if (arguments.length < 1 || xpos === null) xpos = "50%";
		if (arguments.length < 2 || speedFactor === null) speedFactor = 0.1;
		if (arguments.length < 3 || outerHeight === null) outerHeight = true;
		
		// function to be called whenever the window is scrolled or resized
		function update(){
			var pos = $window.scrollTop();				

			$this.each(function(){
				var $element = $(this);
				var top = $element.offset().top;
				var height = getHeight($element);

				// Check if totally above or totally below viewport
				if (top + height < pos || top > pos + windowHeight) {
					return;
				}

				$this.css('backgroundPosition', xpos + " " + Math.round((firstTop - pos) * speedFactor) + "px");
			});
		}		

		$window.bind('scroll', update).resize(update);
		update();
	};
})(jQuery);
 

// Generated by CoffeeScript 1.4.0

/*
countdown is a simple jquery plugin for countdowns

Dual licensed under the MIT (http://www.opensource.org/licenses/mit-license.php)
and GPL-3.0 (http://opensource.org/licenses/GPL-3.0) licenses.

@source: http://github.com/rendro/countdown/
@autor: Robert Fleischmann
@version: 1.0.1
*/


(function() {

  (function($) {
    $.countdown = function(el, options) {
      var getDateData,
        _this = this;
      this.el = el;
      this.$el = $(el);
      this.$el.data("countdown", this);
      this.init = function() {
        _this.options = $.extend({}, $.countdown.defaultOptions, options);
        if (_this.options.refresh) {
          _this.interval = setInterval(function() {
            return _this.render();
          }, _this.options.refresh);
        }
        _this.render();
        return _this;
      };
      getDateData = function(endDate) {
        var dateData, diff;
        endDate = Date.parse($.isPlainObject(_this.options.date) ? _this.options.date : new Date(_this.options.date));
        diff = (endDate - Date.parse(new Date)) / 1000;
        if (diff <= 0) {
          diff = 0;
          if (_this.interval) {
            _this.stop();
          }
          _this.options.onEnd.apply(_this);
        }
        dateData = {
          years: 0,
          days: 0,
          hours: 0,
          min: 0,
          sec: 0,
          millisec: 0
        };
        if (diff >= (365.25 * 86400)) {
          dateData.years = Math.floor(diff / (365.25 * 86400));
          diff -= dateData.years * 365.25 * 86400;
        }
        if (diff >= 86400) {
          dateData.days = Math.floor(diff / 86400);
          diff -= dateData.days * 86400;
        }
        if (diff >= 3600) {
          dateData.hours = Math.floor(diff / 3600);
          diff -= dateData.hours * 3600;
        }
        if (diff >= 60) {
          dateData.min = Math.floor(diff / 60);
          diff -= dateData.min * 60;
        }
        dateData.sec = diff;
        return dateData;
      };
      this.leadingZeros = function(num, length) {
        if (length == null) {
          length = 2;
        }
        num = String(num);
        while (num.length < length) {
          num = "0" + num;
        }
        return num;
      };
      this.update = function(newDate) {
        _this.options.date = newDate;
        return _this;
      };
      this.render = function() {
        _this.options.render.apply(_this, [getDateData(_this.options.date)]);
        return _this;
      };
      this.stop = function() {
        if (_this.interval) {
          clearInterval(_this.interval);
        }
        _this.interval = null;
        return _this;
      };
      this.start = function(refresh) {
        if (refresh == null) {
          refresh = _this.options.refresh || $.countdown.defaultOptions.refresh;
        }
        if (_this.interval) {
          clearInterval(_this.interval);
        }
        _this.render();
        _this.options.refresh = refresh;
        _this.interval = setInterval(function() {
          return _this.render();
        }, _this.options.refresh);
        return _this;
      };
      return this.init();
    };
    $.countdown.defaultOptions = {
      date: "June 7, 2087 15:03:25",
      refresh: 1000,
      onEnd: $.noop,
      render: function(date) {
        return $(this.el).html("" + date.years + " years, " + date.days + " days, " + (this.leadingZeros(date.hours)) + " hours, " + (this.leadingZeros(date.min)) + " min and " + (this.leadingZeros(date.sec)) + " sec");
      }
    };
    $.fn.countdown = function(options) {
      return $.each(this, function(i, el) {
        var $el;
        $el = $(el);
        if (!$el.data('countdown')) {
          return $el.data('countdown', new $.countdown(el, options));
        }
      });
    };
    return void 0;
  })(jQuery);

}).call(this);


/*global jQuery */
/*!
* FitText.js 1.1
*
* Copyright 2011, Dave Rupert http://daverupert.com
* Released under the WTFPL license
* http://sam.zoy.org/wtfpl/
*
* Date: Thu May 05 14:23:00 2011 -0600
*/

(function( $ ){

  $.fn.fitText = function( kompressor, options ) {

    // Setup options
    var compressor = kompressor || 1,
        settings = $.extend({
          'minFontSize' : Number.NEGATIVE_INFINITY,
          'maxFontSize' : Number.POSITIVE_INFINITY
        }, options);

    return this.each(function(){

      // Store the object
      var $this = $(this);

      // Resizer() resizes items based on the object width divided by the compressor * 10
      var resizer = function () {
        $this.css('font-size', Math.max(Math.min($this.width() / (compressor*10), parseFloat(settings.maxFontSize)), parseFloat(settings.minFontSize)));
      };

      // Call once to set.
      resizer();

      // Call on resize. Opera debounces their resize by default.
      $(window).on('resize.fittext orientationchange.fittext', resizer);

    });

  };

})( jQuery );


/**
 * jQuery.marquee - scrolling text horizontally
 * Date: 11/01/2013
 * @author Aamir Afridi - aamirafridi(at)gmail(dot)com / http://aamirafridi.com/jquery/jquery-marquee-plugin
 */
 (function(e){e.fn.marquee=function(t){return this.each(function(){function d(e){var t=[];for(var n in e){if(e.hasOwnProperty(n)){t.push(n+":"+e[n])}}t.push();return"{"+t.join(",")+"}"}function v(){if(l&&n.allowCss3Support){return i.css(f,"paused")}if(e.fn.pause){i.pause();r.trigger("paused")}}function m(){if(l&&n.allowCss3Support){return i.css(f,"running")}if(e.fn.resume){i.resume();r.trigger("resumed")}}var n=e.extend({},e.fn.marquee.defaults,t),r=e(this),i,s,o,u,a,f="animation-play-state",l=false;if(typeof r.data().delaybeforestart!=="undefined"){r.data().delayBeforeStart=r.data().delaybeforestart;delete r.data().delaybeforestart}if(typeof r.data().pauseonhover!=="undefined"){r.data().pauseOnHover=r.data().pauseonhover;delete r.data().pauseonhover}if(typeof r.data().pauseoncycle!=="undefined"){r.data().pauseOnCycle=r.data().pauseoncycle;delete r.data().pauseoncycle}if(typeof r.data().allowcss3support!=="undefined"){r.data().allowCss3Support=r.data().allowcss3support;delete r.data().allowcss3support}n=e.extend({},n,r.data());n.duration=n.speed||n.duration;u=n.direction=="up"||n.direction=="down";n.gap=n.duplicated?n.gap:0;r.wrapInner('<div class="js-marquee"></div>');var c=r.find(".js-marquee").css({"margin-right":n.gap,"float":"left"});if(n.duplicated){c.clone().appendTo(r)}r.wrapInner('<div style="width:100000px" class="js-marquee-wrapper"></div>');i=r.find(".js-marquee-wrapper");if(u){var h=r.height();i.removeAttr("style");r.height(h);r.find(".js-marquee").css({"float":"none","margin-bottom":n.gap,"margin-right":0});if(n.duplicated)r.find(".js-marquee:last").css({"margin-bottom":0});var p=r.find(".js-marquee:first").height()+n.gap;n.duration=(parseInt(p,10)+parseInt(h,10))/parseInt(h,10)*n.duration}else{a=r.find(".js-marquee:first").width()+n.gap;s=r.width();n.duration=(parseInt(a,10)+parseInt(s,10))/parseInt(s,10)*n.duration}if(n.duplicated){n.duration=n.duration/2}if(n.allowCss3Support){var g=document.createElement("div"),y="animation",b="marqueeAnimation-"+Math.floor(Math.random()*1e7),w="Webkit Moz O ms Khtml".split(" "),E="",S="",x=e("style"),T="";if(g.style.animationCssStr){l=true}if(l===false){for(var N=0;N<w.length;N++){if(g.style[w[N]+"AnimationName"]!==undefined){var C="-"+w[N].toLowerCase()+"-";E=C+"animation";f=C+f;T="@"+C+"keyframes "+b+" ";l=true;break}}}if(l){S=b+" "+n.duration/1e3+"s "+n.delayBeforeStart/1e3+"s infinite "+n.css3easing;}}var k=function(){if(u){if(n.duplicated){i.css("margin-top",n.direction=="up"?0:"-"+p+"px");o={"margin-top":n.direction=="up"?"-"+p+"px":0}}else{i.css("margin-top",n.direction=="up"?h+"px":"-"+p+"px");o={"margin-top":n.direction=="up"?"-"+i.height()+"px":h+"px"}}}else{if(n.duplicated){i.css("margin-left",n.direction=="left"?0:"-"+a+"px");o={"margin-left":n.direction=="left"?"-"+a+"px":0}}else{i.css("margin-left",n.direction=="left"?s+"px":"-"+a+"px");o={"margin-left":n.direction=="left"?"-"+a+"px":s+"px"}}}r.trigger("beforeStarting");if(l){i.css(E,S);var t=T+" { 100%  "+d(o)+"}";if(x.length!=0){x.last().append(t)}else{e("head").append("<style>"+t+"</style>")}}else{i.animate(o,n.duration,n.easing,function(){r.trigger("finished");if(n.pauseOnCycle){setTimeout(k,n.delayBeforeStart)}else{k()}})}};r.bind("pause",v);r.bind("resume",m);if(n.pauseOnHover){r.hover(v,m)}if(l&&n.allowCss3Support){k()}else{setTimeout(k,n.delayBeforeStart)}})};e.fn.marquee.defaults={allowCss3Support:true,css3easing:"linear",easing:"linear",delayBeforeStart:0,direction:"left",duplicated:false,duration:5e3,gap:20,pauseOnCycle:false,pauseOnHover:false}})(jQuery);
 
 /*global jQuery */
/*!	
* Lettering.JS 0.6.1
*
* Copyright 2010, Dave Rupert http://daverupert.com
* Released under the WTFPL license 
* http://sam.zoy.org/wtfpl/
*
* Thanks to Paul Irish - http://paulirish.com - for the feedback.
*
* Date: Mon Sep 20 17:14:00 2010 -0600
*/
(function($){
	function injector(t, splitter, klass, after) {
		var a = t.text().split(splitter), inject = '';
		if (a.length) {
			$(a).each(function(i, item) {
				inject += '<span class="'+klass+(i+1)+'">'+item+'</span>'+after;
			});	
			t.empty().append(inject);
		}
	}
	
	var methods = {
		init : function() {

			return this.each(function() {
				injector($(this), '', 'char', '');
			});

		},

		words : function() {

			return this.each(function() {
				injector($(this), ' ', 'word', ' ');
			});

		},
		
		lines : function() {

			return this.each(function() {
				var r = "eefec303079ad17405c889e092e105b0";
				// Because it's hard to split a <br/> tag consistently across browsers,
				// (*ahem* IE *ahem*), we replaces all <br/> instances with an md5 hash 
				// (of the word "split").  If you're trying to use this plugin on that 
				// md5 hash string, it will fail because you're being ridiculous.
				injector($(this).children("br").replaceWith(r).end(), r, 'line', '');
			});

		}
	};

	$.fn.lettering = function( method ) {
		// Method calling logic
		if ( method && methods[method] ) {
			return methods[ method ].apply( this, [].slice.call( arguments, 1 ));
		} else if ( method === 'letters' || ! method ) {
			return methods.init.apply( this, [].slice.call( arguments, 0 ) ); // always pass an array
		}
		$.error( 'Method ' +  method + ' does not exist on jQuery.lettering' );
		return this;
	};

})(jQuery);

/*global jQuery */
/*!	
* Lettering.JS 0.6.1
*
* Copyright 2010, Dave Rupert http://daverupert.com
* Released under the WTFPL license 
* http://sam.zoy.org/wtfpl/
*
* Thanks to Paul Irish - http://paulirish.com - for the feedback.
*
* Date: Mon Sep 20 17:14:00 2010 -0600
*/
(function($){
	function injector(t, splitter, klass, after) {
		var a = t.text().split(splitter), inject = '';
		if (a.length) {
			$(a).each(function(i, item) {
				inject += '<span class="'+klass+(i+1)+'">'+item+'</span>'+after;
			});	
			t.empty().append(inject);
		}
	}
	
	var methods = {
		init : function() {

			return this.each(function() {
				injector($(this), '', 'char', '');
			});

		},

		words : function() {

			return this.each(function() {
				injector($(this), ' ', 'word', ' ');
			});

		},
		
		lines : function() {

			return this.each(function() {
				var r = "eefec303079ad17405c889e092e105b0";
				// Because it's hard to split a <br/> tag consistently across browsers,
				// (*ahem* IE *ahem*), we replaces all <br/> instances with an md5 hash 
				// (of the word "split").  If you're trying to use this plugin on that 
				// md5 hash string, it will fail because you're being ridiculous.
				injector($(this).children("br").replaceWith(r).end(), r, 'line', '');
			});

		}
	};

	$.fn.lettering = function( method ) {
		// Method calling logic
		if ( method && methods[method] ) {
			return methods[ method ].apply( this, [].slice.call( arguments, 1 ));
		} else if ( method === 'letters' || ! method ) {
			return methods.init.apply( this, [].slice.call( arguments, 0 ) ); // always pass an array
		}
		$.error( 'Method ' +  method + ' does not exist on jQuery.lettering' );
		return this;
	};

})(jQuery);
 
 /*
 * textillate.js
 * http://jschr.github.com/textillate
 * MIT licensed
 *
 * Copyright (C) 2012-2013 Jordan Schroter
 */

(function ($) {
  "use strict"; 

  function isInEffect (effect) {
    return /In/.test(effect) || $.inArray(effect, $.fn.textillate.defaults.inEffects) >= 0;
  };

  function isOutEffect (effect) {
    return /Out/.test(effect) || $.inArray(effect, $.fn.textillate.defaults.outEffects) >= 0;
  };

  // custom get data api method
  function getData (node) {
    var attrs = node.attributes || []
      , data = {};

    if (!attrs.length) return data;

    $.each(attrs, function (i, attr) {
      if (/^data-in-*/.test(attr.nodeName)) {
        data.in = data.in || {};
        data.in[attr.nodeName.replace(/data-in-/, '')] = attr.nodeValue;
      } else if (/^data-out-*/.test(attr.nodeName)) {
        data.out = data.out || {};
        data.out[attr.nodeName.replace(/data-out-/, '')] = attr.nodeValue;
      } else if (/^data-*/.test(attr.nodeName)) {
        data[attr.nodeName] = attr.nodeValue;
      }
    })

    return data;
  }

  function shuffle (o) {
      for (var j, x, i = o.length; i; j = parseInt(Math.random() * i), x = o[--i], o[i] = o[j], o[j] = x);
      return o;
  }

  function animate ($c, effect, cb) {
    $c.addClass('animated ' + effect)
      .css('visibility', 'visible')
      .show();

    $c.one('animationend webkitAnimationEnd oAnimationEnd', function () {
        $c.removeClass('animated ' + effect);
        cb && cb();
    });
  }

  function animateChars ($chars, options, cb) {
    var that = this
      , count = $chars.length;

    if (!count) {
      cb && cb();
      return;
    } 

    if (options.shuffle) $chars = shuffle($chars);
    if (options.reverse) $chars = $chars.toArray().reverse();

    $.each($chars, function (i, c) {
      var $char = $(c);
      
      function complete () {
        if (isInEffect(options.effect)) {
          $char.css('visibility', 'visible');
        } else if (isOutEffect(options.effect)) {
          $char.css('visibility', 'hidden');
        }
        count -= 1;
        if (!count && cb) cb();
      }

      var delay = options.sync ? options.delay : options.delay * i * options.delayScale;

      $char.text() ? 
        setTimeout(function () { animate($char, options.effect, complete) }, delay) :
        complete();
    });
  };

  var Textillate = function (element, options) {
    var base = this
      , $element = $(element);

    base.init = function () {
      base.$texts = $element.find(options.selector);
      
      if (!base.$texts.length) {
        base.$texts = $('<ul class="texts"><li>' + $element.html() + '</li></ul>');
        $element.html(base.$texts);
      }

      base.$texts.hide();

      base.$current = $('<span>')
        .text(base.$texts.find(':first-child').html())
        .prependTo($element);

      if (isInEffect(options.effect)) {
        base.$current.css('visibility', 'hidden');
      } else if (isOutEffect(options.effect)) {
        base.$current.css('visibility', 'visible');
      }

      base.setOptions(options);

      setTimeout(function () {
        base.options.autoStart && base.start();
      }, base.options.initialDelay)
    };

    base.setOptions = function (options) {
      base.options = options;
    };

    base.triggerEvent = function (name) {
      var e = $.Event(name + '.tlt');
      $element.trigger(e, base);
      return e;
    };

    base.in = function (index, cb) {
      index = index || 0;
       
      var $elem = base.$texts.find(':nth-child(' + (index + 1) + ')')
        , options = $.extend({}, base.options, getData($elem))
        , $chars;

      $elem.addClass('current');

      base.triggerEvent('inAnimationBegin');

      base.$current
        .text($elem.html())
        .lettering('words');

      base.$current.find('[class^="word"]')
          .css({ 
            'display': 'inline-block',
            // fix for poor ios performance
            '-webkit-transform': 'translate3d(0,0,0)',
               '-moz-transform': 'translate3d(0,0,0)',
                 '-o-transform': 'translate3d(0,0,0)',
                    'transform': 'translate3d(0,0,0)'
          })
          .each(function () { $(this).lettering() });

      $chars = base.$current
        .find('[class^="char"]')
        .css('display', 'inline-block');

      if (isInEffect(options.in.effect)) {
        $chars.css('visibility', 'hidden');
      } else if (isOutEffect(options.in.effect)) {
        $chars.css('visibility', 'visible');
      }

      base.currentIndex = index;

      animateChars($chars, options.in, function () {
        base.triggerEvent('inAnimationEnd');
        if (options.in.callback) options.in.callback();
        if (cb) cb(base);
      });
    };

    base.out = function (cb) {
      var $elem = base.$texts.find(':nth-child(' + (base.currentIndex + 1) + ')')
        , $chars = base.$current.find('[class^="char"]')
        , options = $.extend({}, base.options, getData($elem));

      base.triggerEvent('outAnimationBegin');

      animateChars($chars, options.out, function () {
        $elem.removeClass('current');
        base.triggerEvent('outAnimationEnd');
        if (options.out.callback) options.out.callback();
        if (cb) cb(base);
      });
    };

    base.start = function (index) {
      base.triggerEvent('start');

      (function run (index) {
        base.in(index, function () {
          var length = base.$texts.children().length;

          index += 1;
          
          if (!base.options.loop && index >= length) {
            if (base.options.callback) base.options.callback();
            base.triggerEvent('end');
          } else {
            index = index % length;

            setTimeout(function () {
              base.out(function () {
                run(index)
              });
            }, base.options.minDisplayTime);
          }
        });
      }(index || 0));
    };

    base.init();
  }

  $.fn.textillate = function (settings, args) {
    return this.each(function () {
      var $this = $(this)
        , data = $this.data('textillate')
        , options = $.extend(true, {}, $.fn.textillate.defaults, getData(this), typeof settings == 'object' && settings);

      if (!data) { 
        $this.data('textillate', (data = new Textillate(this, options)));
      } else if (typeof settings == 'string') {
        data[settings].apply(data, [].concat(args));
      } else {
        data.setOptions.call(data, options);
      }
    })
  };
  
  $.fn.textillate.defaults = {
    selector: '.texts',
    loop: false,
    minDisplayTime: 2000,
    initialDelay: 0,
    in: {
      effect: 'fadeInLeftBig',
      delayScale: 1.5,
      delay: 50,
      sync: false,
      reverse: false,
      shuffle: false,
      callback: function () {}
    },
    out: {
      effect: 'hinge',
      delayScale: 1.5,
      delay: 50,
      sync: false,
      reverse: false,
      shuffle: false,
      callback: function () {}
    },
    autoStart: true,
    inEffects: [],
    outEffects: [ 'hinge' ],
    callback: function () {}
  };

}(jQuery));




// Queness Before & After jQuery Plugin 
// Created by Kevin Liew from Queness.com
// Permission is given to use this plugin in whatever way you want :)

	(function($){
    $.fn.extend({
        //plugin name - qbeforeafter
        qbeforeafter: function(options) {
 
            var defaults = {
            	defaultgap: 50,            
            	leftgap: 10,
            	rightgap: 10,
            	caption: false,
            	reveal: 0.5
            };
             
            var options = $.extend(defaults, options);
         
            return this.each(function() {

	            var o = options;
	            var i = $(this);
				var img_mask = i.children('img:eq(0)').attr('src');
				var img_bg = i.children('img:eq(1)').attr('src');
				var img_cap_one = i.children('img:eq(0)').attr('alt');
			
				var width = i.children('img:eq(0)').width();
				var height = i.children('img:eq(0)').height();
				
				i.children('img').hide();		
				
				i.css({'overflow': 'hidden', 'position': 'relative'});
				i.append('<div class="ba-mask"></div>');
				i.append('<div class="ba-bg"></div>');			
				i.append('<div class="ba-caption">' + img_cap_one + '</div>');
				
				i.children('.ba-mask, .ba-bg').width(width);
				i.children('.ba-mask, .ba-bg').height(height);
				i.children('.ba-mask').animate({'width':width - o.defaultgap}, 1000);
			
				i.children('.ba-mask').css('backgroundImage','url(' + img_mask + ')');
				i.children('.ba-bg').css('backgroundImage','url(' + img_bg + ')');	

				if (o.caption) i.children('.ba-caption').show();

            }).mousemove(function (e) {

				var o = options;
				var i = $(this);
				
				pos_img = i.offset()['left'];
				pos_mouse = e.pageX;		
				new_width = pos_mouse - pos_img;
				img_width = i.width();
				img_cap_one = i.children('img:eq(0)').attr('alt');
				img_cap_two = i.children('img:eq(1)').attr('alt');				

				if (new_width > o.leftgap && new_width < (img_width - o.rightgap)) {			
					i.children('.ba-mask').width(new_width);
				}
				
				if (new_width < (img_width * o.reveal)) {			
					i.children('.ba-caption').html(img_cap_two);
				} else {
					i.children('.ba-caption').html(img_cap_one);			
				}					
			
			});
        }
    });
	})(jQuery);	



/*! sly 1.1.0 - 10th Sep 2013 | https://github.com/Darsain/sly */
(function(h,y,sa){function oa(f,ia,m){var ta,u,ua,z,M,y,U,pa;function ca(){var a=0,j=0,b=v.length;e.old=h.extend({},e);s=F?0:C[c.horizontal?"width":"height"]();N=I[c.horizontal?"width":"height"]();n=F?f:r[c.horizontal?"outerWidth":"outerHeight"]();v.length=0;e.start=0;e.end=Math.max(n-s,0);if(D){j=k.length;A=r.children(c.itemSelector);k.length=0;var Da=da(r,c.horizontal?"paddingLeft":"paddingTop"),ia=da(r,c.horizontal?"paddingRight":"paddingBottom"),Ea=da(A,c.horizontal?"marginLeft":"marginTop"),
a=da(A.slice(-1),c.horizontal?"marginRight":"marginBottom"),l=0,q="none"!==A.css("float"),a=Ea?0:a;n=0;A.each(function(a,b){var j=h(b),d=j[c.horizontal?"outerWidth":"outerHeight"](!0),K=da(j,c.horizontal?"marginLeft":"marginTop"),j=da(j,c.horizontal?"marginRight":"marginBottom"),e={el:b,size:d,half:d/2,start:n-(!a||c.horizontal?0:K),center:n-Math.round(s/2-d/2),end:n-s+d-(Ea?0:j)};a||(l=-(J?Math.round(s/2-d/2):0)+Da,n+=Da);n+=d;!c.horizontal&&!q&&j&&(K&&0<a)&&(n-=Math.min(K,j));a===A.length-1&&(n+=
ia);k.push(e)});r[0].style[c.horizontal?"width":"height"]=n+"px";n-=a;e.start=l;e.end=J?k.length?k[k.length-1].center:l:Math.max(n-s,0)}e.center=Math.round(e.end/2+e.start/2);h.extend(g,va(void 0));B.length&&0<N&&(c.dynamicHandle?(O=J?k.length?N*s/(s+k[k.length-1].center-k[0].center):N:N*s/n,O=w(Math.round(O),c.minHandleSize,N),B[0].style[c.horizontal?"width":"height"]=O+"px"):O=B[c.horizontal?"outerWidth":"outerHeight"](),p.end=N-O,V||na());if(!F&&0<s){var m=e.start,a="";if(D)h.each(k,function(a,
j){if(J||j.start+j.size>m)m=j[J?"center":"start"],v.push(m),m+=s});else for(;m-s<e.end;)v.push(m),m+=s;if(W[0]&&b!==v.length){for(b=0;b<v.length;b++)a+=c.pageBuilder.call(d,b);ja=W.html(a).children();ja.eq(g.activePage).addClass(c.activeClass)}}g.slideeSize=n;g.frameSize=s;g.sbSize=N;g.handleSize=O;if(D){if(d.initialized){if(g.activeItem>=k.length||0===j&&0<k.length)qa(0<k.length?k.length-1:0)}else qa(c.startAt),d[P?"toCenter":"toStart"](c.startAt);G(w(e.dest,e.start,e.end))}else d.initialized?G(w(e.dest,
e.start,e.end)):G(c.startAt,1);x("load")}function G(a,j,K){if(D&&b.released&&!K){K=va(a);var f=a>e.start&&a<e.end;P?(f&&(a=k[K.centerItem].center),J&&c.activateMiddle&&qa(K.centerItem)):f&&(a=k[K.firstItem].start)}b.init&&b.slidee&&c.elasticBounds?a>e.end?a=e.end+(a-e.end)/6:a<e.start&&(a=e.start+(a-e.start)/6):a=w(a,e.start,e.end);ta=+new Date;u=0;ua=e.cur;z=a;M=a-e.cur;y=b.tweese||b.init&&!b.slidee;U=!y&&(j||b.init&&b.slidee||!c.speed);b.tweese=0;a!==e.dest&&(e.dest=a,x("change"),V||ba());b.released&&
!d.isPaused&&d.resume();h.extend(g,va(void 0));Fa();ja[0]&&q.page!==g.activePage&&(q.page=g.activePage,ja.removeClass(c.activeClass).eq(g.activePage).addClass(c.activeClass),x("activePage",q.page))}function ba(){V?(U?e.cur=z:y?(pa=z-e.cur,e.cur=0.1>Math.abs(pa)?z:e.cur+pa*(b.released?c.swingSpeed:c.syncSpeed)):(u=Math.min(+new Date-ta,c.speed),e.cur=ua+M*jQuery.easing[c.easing](u/c.speed,u,0,1,c.speed)),z===e.cur?(e.cur=z,b.tweese=V=0):V=ka(ba),x("move"),F||(H?r[0].style[H]=la+(c.horizontal?"translateX":
"translateY")+"("+-e.cur+"px)":r[0].style[c.horizontal?"left":"top"]=-Math.round(e.cur)+"px"),!V&&b.released&&x("moveEnd"),na()):(V=ka(ba),b.released&&x("moveStart"))}function na(){B.length&&(p.cur=e.start===e.end?0:((b.init&&!b.slidee?e.dest:e.cur)-e.start)/(e.end-e.start)*p.end,p.cur=w(Math.round(p.cur),p.start,p.end),q.hPos!==p.cur&&(q.hPos=p.cur,H?B[0].style[H]=la+(c.horizontal?"translateX":"translateY")+"("+p.cur+"px)":B[0].style[c.horizontal?"left":"top"]=p.cur+"px"))}function Ga(){(!t.speed||
e.cur===(0<t.speed?e.end:e.start))&&d.stop();Ha=b.init?ka(Ga):0;t.now=+new Date;t.pos=e.cur+(t.now-t.lastTime)/1E3*t.speed;G(b.init?t.pos:Math.round(t.pos));!b.init&&e.cur===e.dest&&x("moveEnd");t.lastTime=t.now}function wa(a,j,b){"boolean"===Q(j)&&(b=j,j=sa);j===sa?G(e[a],b):P&&"center"!==a||(j=d.getPos(j))&&G(j[a],b,!P)}function ra(a){return"undefined"!==Q(a)?R(a)?0<=a&&a<k.length?a:-1:A.index(a):-1}function xa(a){return ra(R(a)&&0>a?a+k.length:a)}function qa(a){a=ra(a);if(!D||0>a)return!1;q.active!==
a&&(A.eq(g.activeItem).removeClass(c.activeClass),A.eq(a).addClass(c.activeClass),q.active=g.activeItem=a,Fa(),x("active",a));return a}function va(a){a=w(R(a)?a:e.dest,e.start,e.end);var j={},b=J?0:s/2;if(!F)for(var c=0,d=v.length;c<d;c++){if(a>=e.end||c===v.length-1){j.activePage=v.length-1;break}if(a<=v[c]+b){j.activePage=c;break}}if(D){for(var d=c=b=!1,f=0,g=k.length;f<g;f++)if(!1===b&&a<=k[f].start+k[f].half&&(b=f),!1===d&&a<=k[f].center+k[f].half&&(d=f),f===g-1||a<=k[f].end+k[f].half){c=f;break}j.firstItem=
R(b)?b:0;j.centerItem=R(d)?d:j.firstItem;j.lastItem=R(c)?c:j.centerItem}return j}function Fa(){var a=e.dest<=e.start,j=e.dest>=e.end,d=a?1:j?2:3;q.slideePosState!==d&&(q.slideePosState=d,X.is("button,input")&&X.prop("disabled",a),Y.is("button,input")&&Y.prop("disabled",j),X.add(ea)[a?"addClass":"removeClass"](c.disabledClass),Y.add(Z)[j?"addClass":"removeClass"](c.disabledClass));q.fwdbwdState!==d&&b.released&&(q.fwdbwdState=d,ea.is("button,input")&&ea.prop("disabled",a),Z.is("button,input")&&Z.prop("disabled",
j));D&&(a=0===g.activeItem,j=g.activeItem>=k.length-1,d=a?1:j?2:3,q.itemsButtonState!==d&&(q.itemsButtonState=d,$.is("button,input")&&$.prop("disabled",a),aa.is("button,input")&&aa.prop("disabled",j),$[a?"addClass":"removeClass"](c.disabledClass),aa[j?"addClass":"removeClass"](c.disabledClass)))}function Ia(a,b,c){a=xa(a);b=xa(b);if(-1<a&&-1<b&&a!==b&&(!c||b!==a-1)&&(c||b!==a+1)){A.eq(a)[c?"insertAfter":"insertBefore"](k[b].el);var d=a<b?a:c?b:b-1,e=a>b?a:c?b+1:b,f=a>b;a===g.activeItem?q.active=g.activeItem=
c?f?b+1:b:f?b:b-1:g.activeItem>d&&g.activeItem<e&&(q.active=g.activeItem+=f?1:-1);ca()}}function Ja(a,b){for(var c=0,d=E[a].length;c<d;c++)if(E[a][c]===b)return c;return-1}function Ka(a){return Math.round(w(a,p.start,p.end)/p.end*(e.end-e.start))+e.start}function Ba(){b.history[0]=b.history[1];b.history[1]=b.history[2];b.history[2]=b.history[3];b.history[3]=b.delta}function La(a){b.released=0;b.source=a;b.slidee="slidee"===a}function Ma(a){if(!b.init){var d="touchstart"===a.type,f=a.data.source,g=
"slidee"===f;if(!("handle"===f&&(!c.dragHandle||p.start===p.end)))if(!g||(d?c.touchDragging:c.mouseDragging&&2>a.which))d||L(a,1),La(f),b.$source=h(a.target),b.init=0,b.touch=d,b.pointer=d?a.originalEvent.touches[0]:a,b.initX=b.pointer.pageX,b.initY=b.pointer.pageY,b.initPos=g?e.cur:p.cur,b.start=+new Date,b.time=0,b.path=0,b.pathToInit=g?d?50:10:0,b.history=[0,0,0,0],b.initLoc=b[c.horizontal?"initX":"initY"],b.deltaMin=g?-b.initLoc:-p.cur,b.deltaMax=g?document[c.horizontal?"width":"height"]-b.initLoc:
p.end-p.cur,(g?r:B).addClass(c.draggedClass),fa.on(d?Na:Oa,Pa),g&&(Qa=setInterval(Ba,10))}}function Pa(a){b.released="mouseup"===a.type||"touchend"===a.type;b.pointer=b.touch?a.originalEvent[b.released?"changedTouches":"touches"][0]:a;b.pathX=b.pointer.pageX-b.initX;b.pathY=b.pointer.pageY-b.initY;b.pathTotal=Math.sqrt(Math.pow(b.pathX,2)+Math.pow(b.pathY,2));b.delta=w(c.horizontal?b.pathX:b.pathY,b.deltaMin,b.deltaMax);if(!b.init&&b.pathTotal>b.pathToInit){if(b.slidee){if(c.horizontal?Math.abs(b.pathX)<
Math.abs(b.pathY):Math.abs(b.pathX)>Math.abs(b.pathY)){ya();return}b.$source.on(ga,Ra)}b.init=1;d.pause(1);x("moveStart")}b.init?(b.released?(b.touch||L(a),ya(),c.releaseSwing&&b.slidee&&(b.swing=300*((b.delta-b.history[0])/40),b.delta+=b.swing,b.tweese=10<Math.abs(b.swing))):L(a),G(b.slidee?Math.round(b.initPos-b.delta):Ka(b.initPos+b.delta))):b.released&&ya()}function ya(){clearInterval(Qa);fa.off(b.touch?Na:Oa,Pa);(b.slidee?r:B).removeClass(c.draggedClass);d.resume(1);e.cur===e.dest&&b.init&&x("moveEnd");
b.init=0}function Sa(){d.stop();fa.off("mouseup",Sa)}function ha(a){L(a);switch(this){case Z[0]:case ea[0]:d.moveBy(Z.is(this)?c.moveBy:-c.moveBy);fa.on("mouseup",Sa);break;case $[0]:d.prev();break;case aa[0]:d.next();break;case X[0]:d.prevPage();break;case Y[0]:d.nextPage()}}function Ca(a){c.scrollBy&&e.start!==e.end&&(L(a,1),d.slideBy(c.scrollBy*w(-a.originalEvent.wheelDelta||a.originalEvent.detail||a.originalEvent.deltaY,-1,1)))}function Wa(a){c.clickBar&&a.target===I[0]&&(L(a),G(Ka((c.horizontal?
a.pageX-I.offset().left:a.pageY-I.offset().top)-O/2)))}function Xa(a){if(c.keyboardNavBy)switch(a.which){case c.horizontal?37:38:L(a);d["pages"===c.keyboardNavBy?"prevPage":"prev"]();break;case c.horizontal?39:40:L(a),d["pages"===c.keyboardNavBy?"nextPage":"next"]()}}function Ya(){this.parentNode===r[0]&&d.activate(this)}function Za(){this.parentNode===W[0]&&d.activatePage(ja.index(this))}function $a(a){if(c.pauseOnHover)d["mouseenter"===a.type?"pause":"resume"](2)}function x(a,b){if(E[a]){za=E[a].length;
for(S=Aa.length=0;S<za;S++)Aa.push(E[a][S]);for(S=0;S<za;S++)Aa[S].call(d,a,b)}}var c=h.extend({},oa.defaults,ia),d=this,F=R(f),C=h(f),r=C.children().eq(0),s=0,n=0,e={start:0,center:0,end:0,cur:0,dest:0},I=h(c.scrollBar).eq(0),B=I.children().eq(0),N=0,O=0,p={start:0,end:0,cur:0},W=h(c.pagesBar),ja=0,v=[],A=0,k=[],g={firstItem:0,lastItem:0,centerItem:0,activeItem:-1,activePage:0};ia="basic"===c.itemNav;var J="forceCentered"===c.itemNav,P="centered"===c.itemNav||J,D=!F&&(ia||P||J),Ta=c.scrollSource?
h(c.scrollSource):C,ab=c.dragSource?h(c.dragSource):C,Z=h(c.forward),ea=h(c.backward),$=h(c.prev),aa=h(c.next),X=h(c.prevPage),Y=h(c.nextPage),E={},q={};pa=U=y=M=z=ua=u=ta=void 0;var t={},b={released:1},V=0,Qa=0,T=0,Ha=0,S,za;F||(f=C[0]);d.initialized=0;d.frame=f;d.slidee=r[0];d.pos=e;d.rel=g;d.items=k;d.pages=v;d.isPaused=0;d.options=c;d.reload=ca;d.getPos=function(a){if(D)return a=ra(a),-1!==a?k[a]:!1;var b=r.find(a).eq(0);return b[0]?(a=c.horizontal?b.offset().left-r.offset().left:b.offset().top-
r.offset().top,b=b[c.horizontal?"outerWidth":"outerHeight"](),{start:a,center:a-s/2+b/2,end:a-s+b,size:b}):!1};d.moveBy=function(a){t.speed=a;if(!b.init&&t.speed&&e.cur!==(0<t.speed?e.end:e.start))t.lastTime=+new Date,t.startPos=e.cur,La("button"),b.init=1,x("moveStart"),ma(Ha),Ga()};d.stop=function(){"button"===b.source&&(b.init=0,b.released=1)};d.prev=function(){d.activate(g.activeItem-1)};d.next=function(){d.activate(g.activeItem+1)};d.prevPage=function(){d.activatePage(g.activePage-1)};d.nextPage=
function(){d.activatePage(g.activePage+1)};d.slideBy=function(a,b){if(D)d[P?"toCenter":"toStart"](w((P?g.centerItem:g.firstItem)+c.scrollBy*a,0,k.length));else G(e.dest+a,b)};d.slideTo=function(a,b){G(a,b)};d.toStart=function(a,b){wa("start",a,b)};d.toEnd=function(a,b){wa("end",a,b)};d.toCenter=function(a,b){wa("center",a,b)};d.getIndex=ra;d.activate=function(a,e){var f=qa(a);c.smart&&!1!==f&&(P?d.toCenter(f,e):f>=g.lastItem?d.toStart(f,e):f<=g.firstItem?d.toEnd(f,e):b.released&&!d.isPaused&&d.resume())};
d.activatePage=function(a,b){R(a)&&G(v[w(a,0,v.length-1)],b)};d.resume=function(a){if(c.cycleBy&&c.cycleInterval&&!("items"===c.cycleBy&&!k[0]||a<d.isPaused))d.isPaused=0,T?T=clearTimeout(T):x("resume"),T=setTimeout(function(){x("cycle");switch(c.cycleBy){case "items":d.activate(g.activeItem>=k.length-1?0:g.activeItem+1);break;case "pages":d.activatePage(g.activePage>=v.length-1?0:g.activePage+1)}},c.cycleInterval)};d.pause=function(a){a<d.isPaused||(d.isPaused=a||100,T&&(T=clearTimeout(T),x("pause")))};
d.toggle=function(){d[T?"pause":"resume"]()};d.set=function(a,b){h.isPlainObject(a)?h.extend(c,a):c.hasOwnProperty(a)&&(c[a]=b)};d.add=function(a,b){var c=h(a);D?("undefined"===Q(b)||!k[0]?c.appendTo(r):k.length&&c.insertBefore(k[b].el),b<=g.activeItem&&(q.active=g.activeItem+=c.length)):r.append(c);ca()};d.remove=function(a){if(D){if(a=xa(a),-1<a){A.eq(a).remove();var b=a===g.activeItem&&!(J&&c.activateMiddle);a<g.activeItem&&(q.active=--g.activeItem);ca();b&&(q.active=null,d.activate(g.activeItem))}}else h(a).remove(),
ca()};d.moveAfter=function(a,b){Ia(a,b,1)};d.moveBefore=function(a,b){Ia(a,b)};d.on=function(a,b){if("object"===Q(a))for(var c in a){if(a.hasOwnProperty(c))d.on(c,a[c])}else if("function"===Q(b)){c=a.split(" ");for(var e=0,f=c.length;e<f;e++)E[c[e]]=E[c[e]]||[],-1===Ja(c[e],b)&&E[c[e]].push(b)}else if("array"===Q(b)){c=0;for(e=b.length;c<e;c++)d.on(a,b[c])}};d.one=function(a,b){function c(){b.apply(d,arguments);d.off(a,c)}d.on(a,c)};d.off=function(a,b){if(b instanceof Array)for(var c=0,e=b.length;c<
e;c++)d.off(a,b[c]);else for(var c=a.split(" "),e=0,f=c.length;e<f;e++)if(E[c[e]]=E[c[e]]||[],"undefined"===Q(b))E[c[e]].length=0;else{var g=Ja(c[e],b);-1!==g&&E[c[e]].splice(g,1)}};d.destroy=function(){fa.add(Ta).add(B).add(I).add(W).add(Z).add(ea).add($).add(aa).add(X).add(Y).unbind("."+l);$.add(aa).add(X).add(Y).removeClass(c.disabledClass);A&&A.eq(g.activeItem).removeClass(c.activeClass);W.empty();F||(C.unbind("."+l),r.add(B).css(H||(c.horizontal?"left":"top"),H?"none":0),h.removeData(f,l));d.initialized=
0;return d};d.init=function(){if(!d.initialized){d.on(m);var a=B;F||(a=a.add(r),C.css("overflow","hidden"),!H&&"static"===C.css("position")&&C.css("position","relative"));H?la&&a.css(H,la):("static"===I.css("position")&&I.css("position","relative"),a.css({position:"absolute"}));if(c.forward)Z.on(Ua,ha);if(c.backward)ea.on(Ua,ha);if(c.prev)$.on(ga,ha);if(c.next)aa.on(ga,ha);if(c.prevPage)X.on(ga,ha);if(c.nextPage)Y.on(ga,ha);Ta.on("DOMMouseScroll."+l+" mousewheel."+l,Ca);if(I[0])I.on(ga,Wa);if(D&&
c.activateOn)C.on(c.activateOn+"."+l,"*",Ya);if(W[0]&&c.activatePageOn)W.on(c.activatePageOn+"."+l,"*",Za);ab.on(Va,{source:"slidee"},Ma);if(B)B.on(Va,{source:"handle"},Ma);fa.bind("keydown."+l,Xa);F||(C.on("mouseenter."+l+" mouseleave."+l,$a),C.on("scroll."+l,bb));ca();if(c.cycleBy&&!F)d[c.startPaused?"pause":"resume"]();d.initialized=1;return d}}}function Q(f){return null==f?String(f):"object"===typeof f||"function"===typeof f?Object.prototype.toString.call(f).match(/\s([a-z]+)/i)[1].toLowerCase()||
"object":typeof f}function L(f,h){f.preventDefault();h&&f.stopPropagation()}function Ra(f){L(f,1);h(this).off(f.type,Ra)}function bb(){this.scrollTop=this.scrollLeft=0}function R(f){return!isNaN(parseFloat(f))&&isFinite(f)}function da(f,h){return parseInt(f.css(h),10)||0}function w(f,h,m){return f<h?h:f>m?m:f}for(var l="sly",ma=y.cancelAnimationFrame||y.cancelRequestAnimationFrame,ka=y.requestAnimationFrame,H,la,fa=h(document),Va="touchstart."+l+" mousedown."+l,Oa="mousemove."+l+" mouseup."+l,Na=
"touchmove."+l+" touchend."+l,ga="click."+l,Ua="mousedown."+l,Aa=[],U=window,u=["moz","webkit","o"],na=0,M=0,Ba=u.length;M<Ba&&!ma;++M)ka=(ma=U[u[M]+"CancelAnimationFrame"]||U[u[M]+"CancelRequestAnimationFrame"])&&U[u[M]+"RequestAnimationFrame"];ma||(ka=function(f){var h=+new Date,m=Math.max(0,16-(h-na));na=h+m;return U.setTimeout(function(){f(h+m)},m)},ma=function(f){clearTimeout(f)});var u=function(f){for(var h=0,m=ba.length;h<m;h++){var l=ba[h]?ba[h]+f.charAt(0).toUpperCase()+f.slice(1):f;if(Ca.style[l]!==
sa)return l}},ba=["","webkit","moz","ms","o"],Ca=document.createElement("div");H=u("transform");la=u("perspective")?"translateZ(0) ":"";y.Sly=oa;h.fn.sly=function(f,u){var m,w;if(!h.isPlainObject(f)){if("string"===Q(f)||!1===f)m=!1===f?"destroy":f,w=Array.prototype.slice.call(arguments,1);f={}}return this.each(function(H,y){var z=h.data(y,l);!z&&!m?h.data(y,l,(new oa(y,f,u)).init()):z&&m&&z[m]&&z[m].apply(z,w)})};oa.defaults={horizontal:0,itemNav:null,itemSelector:null,smart:0,activateOn:null,activateMiddle:0,
scrollSource:null,scrollBy:0,dragSource:null,mouseDragging:0,touchDragging:0,releaseSwing:0,swingSpeed:0.2,elasticBounds:0,scrollBar:null,dragHandle:0,dynamicHandle:0,minHandleSize:50,clickBar:0,syncSpeed:0.5,pagesBar:null,activatePageOn:null,pageBuilder:function(f){return"<li>"+(f+1)+"</li>"},forward:null,backward:null,prev:null,next:null,prevPage:null,nextPage:null,cycleBy:null,cycleInterval:5E3,pauseOnHover:0,startPaused:0,moveBy:300,speed:0,easing:"swing",startAt:0,keyboardNavBy:null,draggedClass:"dragged",
activeClass:"active",disabledClass:"disabled"}})(jQuery,window);